@@ -1,5 +1,6 @@
 /* This file is part of Step.
    Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
 
    Step is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,26 +18,30 @@
 */
 
 #include "softbodygraphics.h"
-#include "softbodygraphics.moc"
 
 #include <stepcore/softbody.h>
 #include <stepcore/types.h>
 
 #include "ui_create_softbody_items.h"
 
+#include <float.h>
+
 #include "worldmodel.h"
 #include "worldfactory.h"
+
 #include <QItemSelectionModel>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsScene>
 #include <QEvent>
 #include <QPainter>
-#include <QValidator>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
+
 #include <KDebug>
-#include <KDialog>
-#include <KLocale>
+#include <KLocalizedString>
 
-#include <float.h>
 
 void SoftBodyCreator::start()
 {
@@ -95,8 +100,8 @@ void SoftBodyMenuHandler::populateMenu(QMenu* menu, KActionCollection* actions)
 
     // XXX: better icon
     // TODO: This will never work the way SoftBody is right now...
-    //menu->addAction(KIcon("step_object_GasParticle"), i18n("Create items..."), this, SLOT(createSoftBodyItems()));
-    //menu->addAction(KIcon("edit-clear"), i18n("Clear gas"), this, SLOT(clearGas()));
+    //menu->addAction(QIcon::fromTheme("step_object_GasParticle"), i18n("Create items..."), this, SLOT(createSoftBodyItems()));
+    //menu->addAction(QIcon::fromTheme("edit-clear"), i18n("Clear gas"), this, SLOT(clearGas()));
     menu->addSeparator();
     ItemMenuHandler::populateMenu(menu, actions);
 }
@@ -116,13 +121,25 @@ void SoftBodyMenuHandler::createSoftBodyItems(const StepCore::Vector2d& pos)
     if(_worldModel->isSimulationActive())
         _worldModel->simulationStop();
 
-    _createSoftBodyItemsDialog = new KDialog(); // XXX: parent?
+    _createSoftBodyItemsDialog = new QDialog(); // XXX: parent?
     
-    _createSoftBodyItemsDialog->setCaption(i18n("Create soft body items"));
-    _createSoftBodyItemsDialog->setButtons(KDialog::Ok | KDialog::Cancel);
+    _createSoftBodyItemsDialog->setWindowTitle(i18n("Create soft body items"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QWidget *mainWidget = new QWidget();
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    _createSoftBodyItemsDialog->setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    _createSoftBodyItemsDialog->connect(buttonBox, SIGNAL(accepted()),
+					_createSoftBodyItemsDialog, SLOT(accept()));
+    _createSoftBodyItemsDialog->connect(buttonBox, SIGNAL(rejected()),
+					_createSoftBodyItemsDialog, SLOT(reject()));
+    mainLayout->addWidget(buttonBox);
 
     _createSoftBodyItemsUi = new Ui::WidgetCreateSoftBodyItems;
-    _createSoftBodyItemsUi->setupUi(_createSoftBodyItemsDialog->mainWidget());
+    _createSoftBodyItemsUi->setupUi(mainWidget);
 
     _createSoftBodyItemsUi->lineEditPosition->setValidator(
                 new QRegExpValidator(QRegExp("^\\([+-]?\\d+(\\.\\d*)?([eE]\\d*)?,[+-]?\\d+(\\.\\d*)?([eE]\\d*)?\\)$"),
@@ -141,9 +158,10 @@ void SoftBodyMenuHandler::createSoftBodyItems(const StepCore::Vector2d& pos)
     _createSoftBodyItemsUi->lineEditYoungModulus->setValidator(
                 new QDoubleValidator(0, HUGE_VAL, DBL_DIG, _createSoftBodyItemsUi->lineEditYoungModulus));
 
-    connect(_createSoftBodyItemsDialog, SIGNAL(okClicked()), this, SLOT(createSoftBodyItemsApply()));
-
-    _createSoftBodyItemsDialog->exec();
+    int retval = _createSoftBodyItemsDialog->exec();
+    if (retval == QDialog::Accepted) {
+	createSoftBodyItemsApply();
+    }
 
     delete _createSoftBodyItemsDialog; _createSoftBodyItemsDialog = 0;
     delete _createSoftBodyItemsUi; _createSoftBodyItemsUi = 0;
